@@ -39,6 +39,8 @@
 #' weighting is desired.
 #' @param fs The font size used in the plot.
 #' @param lwd The line width used in the plot.
+#' @param xlab A string or expression giving the x-axis label.
+#' @param ylab A string or expression giving the y-axis label.
 #' @author Jeremy Oakley <j.oakley@@sheffield.ac.uk>
 #' @examples
 #' 
@@ -87,7 +89,9 @@ plotfit <- function(fit,
                     ind = TRUE, 
                     lpw = 1,
                     fs = 12,
-                    lwd = 1){
+                    lwd = 1,
+                    xlab = "x",
+                    ylab = expression(f[X](x))){
   
 
   if(d=="beta" & (min(fit$limits) == -Inf | max(fit$limits) == Inf )){stop("Parameter limits must be finite to fit a beta distribution")}
@@ -102,8 +106,8 @@ plotfit <- function(fit,
   if(nrow(fit$vals)>1 & is.na(ex)==T & lp==F){
     if(xl == -Inf & min(fit$limits[,1]) > -Inf){xl <- min(fit$limits[,1]) }
     if(xu == Inf & max(fit$limits[,2]) < Inf){xu <- max(fit$limits[,2]) }
-    if(int == FALSE){suppressWarnings(print(makeGroupPlot(fit, xl, xu, d, lwd)))}else{
-      shinyplotgroup(fit, xl, xu, lpw, lwd)
+    if(int == FALSE){suppressWarnings(print(makeGroupPlot(fit, xl, xu, d, lwd, xlab, ylab)))}else{
+      shinyplotgroup(fit, xl, xu, lpw, lwd, xlab, ylab)
     }
   }
   
@@ -120,8 +124,8 @@ plotfit <- function(fit,
       f2 <- feedback(fit, quantiles=0.99, dist=d)
       xu <- max(f2$expert.quantiles)
     }
-    if(int == FALSE){print(makeLinearPoolPlot(fit, xl, xu,  d , lpw, lwd))}else{
-      shinyplotgroup(fit, xl, xu, lpw, lwd)
+    if(int == FALSE){print(makeLinearPoolPlot(fit, xl, xu,  d , lpw, lwd, xlab, ylab))}else{
+      shinyplotgroup(fit, xl, xu, lpw, lwd, xlab, ylab)
     }
     
   }
@@ -129,16 +133,16 @@ plotfit <- function(fit,
   if(nrow(fit$vals)>1 & is.na(ex)==F){
     if(xl == -Inf & fit$limits[ex,1] > -Inf){xl <- fit$limits[ex,1] }
     if(xu == Inf & fit$limits[ex,2] < Inf){xu <- fit$limits[ex,2] }
-    if(int == FALSE){print(suppressWarnings(makeSingleExpertPlot(fit, d, xl, xu, ql, qu, sf, ex = 1, lwd)))}else{
-      shinyplotsingle(fit, xl, xu, ql, qu, ex)
+    if(int == FALSE){print(suppressWarnings(makeSingleExpertPlot(fit, d, xl, xu, ql, qu, sf, ex = 1, lwd, xlab, ylab)))}else{
+      shinyplotsingle(fit, xl, xu, ql, qu, ex, xlab, ylab)
     }
     
   }
   
  
   if(nrow(fit$vals)==1){
-    if(int == FALSE){print(suppressWarnings(makeSingleExpertPlot(fit, d, xl, xu, ql, qu, sf, ex = 1, lwd)))}else{
-      suppressWarnings(shinyplotsingle(fit, xl, xu, ql, qu, ex = 1))
+    if(int == FALSE){print(suppressWarnings(makeSingleExpertPlot(fit, d, xl, xu, ql, qu, sf, ex = 1, lwd, xlab, ylab)))}else{
+      suppressWarnings(shinyplotsingle(fit, xl, xu, ql, qu, ex = 1, xlab, ylab))
     }
   }
 
